Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
commiteaf1cdd3836aa425e3dc6f1a11d4556bd7e3e876 (patch)
treefe8e701c3e3daa38749b78238858edbbbfea1f91 /source/blender/python/api2_2x/Object.h
parent569a32a2ea3a1992eaeaa5dc0256c48e8a053fbd (diff)
- More renaming all around to follow our conventions
- Implemented partially Blender.Sys - Worked on issues related to sys, path - Took away most "debug" printfs
Diffstat (limited to 'source/blender/python/api2_2x/Object.h')
-rw-r--r--source/blender/python/api2_2x/Object.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/python/api2_2x/Object.h b/source/blender/python/api2_2x/Object.h
index b64977c17be..604ac4b6a3c 100644
--- a/source/blender/python/api2_2x/Object.h
+++ b/source/blender/python/api2_2x/Object.h
@@ -60,13 +60,13 @@
/* The Object PyType Object defined in Object.c */
extern PyTypeObject Object_Type;
-#define C_Object_Check(v) \
+#define BPy_Object_Check(v) \
((v)->ob_type == &Object_Type) /* for type checking */
/*****************************************************************************/
/* Python C_Object structure definition. */
/*****************************************************************************/
-struct C_Object;
+struct BPy_Object;
typedef struct {
PyObject_HEAD
@@ -78,11 +78,11 @@ typedef struct {
/* points to the parent object. This is only set when there's a valid */
/* PyObject (already created at some point). */
- struct C_Object * parent;
+ struct BPy_Object * parent;
/* points to the object that is tracking this object. This is only set */
/* when there's a valid PyObject (already created at some point). */
- struct C_Object * track;
-} C_Object;
+ struct BPy_Object * track;
+} BPy_Object;
#endif /* EXPP_OBJECT_H */
@@ -60,13 +60,13 @@
((v)->ob_type == &Object_Type) /* for type checking */
/*****************************************************************************/
-/* Python C_Object structure definition. */
+/* Python BPy_Object structure definition. */
/*****************************************************************************/